@@ -2,13 +2,16 @@
 
 
 class Proto:
-    ADD_ATTENTION = "add-attention"
     ADD_REVIEWER = "add-reviewer"
     DELETE_REVIEWER = "delete-reviewer"
+    ADD_ATTENTION = "add-attention"
     REMOVE_ATTENTION = "remove-attention"
+    APPROVE_CHANGE = "approve-change"
+    SUBMIT_CHANGE = "submit-change"
 
 
 class Separator:
-    ACCOUNT = ","
     ACTION = ":"
+    CONTENT = ","
     GROUP = " "
+    LABEL = "="
